Tutorials
=========

The best way to learn about GluonTS is to dive right in by following our tutorials. You can download each tutorial as a Jupyter notebook by clicking the *download* link at the top of each tutorial page.

Forecasting
-----------

.. container:: cards

   .. card::
      :title: Quick Start Tutorial
      :link: basic_forecasting_tutorial/tutorial.html

   .. card::
      :title: Extended Forecasting Tutorial
      :link: extended_forecasting_tutorial/extended_tutorial.html


.. toctree::
   :hidden:
   :maxdepth: 1

   basic_forecasting_tutorial/tutorial.ipynb
   extended_forecasting_tutorial/extended_tutorial.ipynb
